pub enum ViewError {
Alignment(Bytes),
Size(Bytes),
Validity(Bytes),
}Expand description
Errors that can occur when constructing a View.
Variants
Alignment(Bytes)
The provided bytes were not properly aligned for the target type.
Size(Bytes)
The provided bytes were of incorrect size for the target type.
Validity(Bytes)
The bytes contained invalid data for the target type.